==> rxjava-1.1.10-sources.jar: rx/schedulers/Timestamped.java <==
/**
 * Copyright 2014 Netflix, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package rx.schedulers;

/**
 * Composite class that takes a value and a timestamp and wraps them.
 * @param <T> the value type held along with the timestamp
 */
public final class Timestamped<T> {
    private final long timestampMillis;
    private final T value;

    public Timestamped(long timestampMillis, T value) {
        this.value = value;
        this.timestampMillis = timestampMillis;
    }

    /**
     * Returns the timestamp, expressed in milliseconds.
     * 
     * @return timestamp in milliseconds
     */
    public long getTimestampMillis() {
        return timestampMillis;
    }

    /**
     * Returns the value embedded in the {@code Timestamped} object.
     * 
     * @return the value
     */
    public T getValue() {
        return value;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof Timestamped)) {
            return false;
        }
        Timestamped<?> other = (Timestamped<?>) obj;
        if (timestampMillis != other.timestampMillis) {
            return false;
        }
        return (value == other.value) || (value != null && value.equals(other.value));
    }

    @Override
    public int hashCode() {
        int prime = 31;
        int result = 1;
        result = prime * result + (int) (timestampMillis ^ (timestampMillis >>> 32));
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        return result;
    }

    @Override
    public String toString() {
        return String.format("Timestamped(timestampMillis = %d, value = %s)", timestampMillis, value.toString());
    }
}

==> rxjava-1.3.8-sources.jar: rx/schedulers/Timestamped.java <==
/**
 * Copyright 2014 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package rx.schedulers;

/**
 * Composite class that takes a value and a timestamp and wraps them.
 * @param <T> the value type held along with the timestamp
 */
public final class Timestamped<T> {
    private final long timestampMillis;
    private final T value;

    public Timestamped(long timestampMillis, T value) {
        this.value = value;
        this.timestampMillis = timestampMillis;
    }

    /**
     * Returns the timestamp, expressed in milliseconds.
     *
     * @return timestamp in milliseconds
     */
    public long getTimestampMillis() {
        return timestampMillis;
    }

    /**
     * Returns the value embedded in the {@code Timestamped} object.
     *
     * @return the value
     */
    public T getValue() {
        return value;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof Timestamped)) {
            return false;
        }
        Timestamped<?> other = (Timestamped<?>) obj;
        return timestampMillis == other.timestampMillis && ((value == other.value) || (value != null && value.equals(other.value)));
    }

    @Override
    public int hashCode() {
        int prime = 31;
        int result = 1;
        result = prime * result + (int) (timestampMillis ^ (timestampMillis >>> 32));
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        return result;
    }

    @Override
    public String toString() {
        return String.format("Timestamped(timestampMillis = %d, value = %s)", timestampMillis, value.toString());
    }
}
